@@ -1,8 +1,8 @@
 ;; -*- no-byte-compile: t; lexical-binding: nil -*-
-(define-package "cond-let" "0.2.2"
+(define-package "cond-let" "20251019.2020"
   "Additional and improved binding conditionals."
   '((emacs "28.1"))
   :url "https://github.com/tarsius/cond-let"
-  :commit "8bf87d45e169ebc091103b2aae325aece3aa804d"
-  :revdesc "v0.2.2-0-g8bf87d45e169"
+  :commit "09ebf1caa81c99677ce74091a23b48a28d53bcd9"
+  :revdesc "09ebf1caa81c"
   :keywords '("extensions"))
